@@ -1,4 +1,4 @@
-import dvc.utils.diff
+from dvc.utils.diff import format_dict, diff as _diff
 from dvc.exceptions import NoMetricsError
 
 
@@ -13,7 +13,11 @@ def _get_metrics(repo, *args, rev=None, **kwargs):
 
 
 def diff(repo, *args, a_rev=None, b_rev=None, **kwargs):
+    with_unchanged = kwargs.pop("all", False)
+
     old = _get_metrics(repo, *args, **kwargs, rev=(a_rev or "HEAD"))
     new = _get_metrics(repo, *args, **kwargs, rev=b_rev)
 
-    return dvc.utils.diff.diff(old, new)
+    return _diff(
+        format_dict(old), format_dict(new), with_unchanged=with_unchanged
+    )
